<?php
namespace Elementor;

class Post_Tag extends Widget_Base {
	
	public function get_name() {
		return 'post-tag';
	}
	
	public function get_title() {
		return __( 'Single Tags', 'sigma-theme' );
	}
	
	public function get_icon() {
		return 'eicon-animated-headline';
	}
	
	public function get_categories() {
		return [ 'Sigma-Single' ];
	}
    
	protected function _register_controls() {
		
        $this->start_controls_section(
        	'section_tag_style',
        	[
				'label' => __( 'Single tag Style', 'sigma-theme' ),
        		'tab' => \Elementor\Controls_Manager::TAB_STYLE,
        	]
        );	 
        
		$this->add_control(
			'sgm_tag_alignment',
			[
				'label' => __( 'Alignment', 'plugin-domain' ),
				'type' => \Elementor\Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'tag' => __( 'Left', 'plugin-domain' ),
						'icon' => 'fa fa-align-left',
					],
					'center' => [
						'tag' => __( 'Center', 'plugin-domain' ),
						'icon' => 'fa fa-align-center',
					],
					'right' => [
						'tag' => __( 'Right', 'plugin-domain' ),
						'icon' => 'fa fa-align-right',
					],
				],
				'default' => 'right',
				'toggle' => true,
                'selectors' => [
                    '{{WRAPPER}} h1.entry-tag' => 'text-align: {{VALUE}};'
                ],				
			]
		);

		$this->add_control(
			'sgm_tag_tag_color',
			[
				'label' => __( 'tag Color', 'sigma-theme' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'scheme' => [
					'type' => \Elementor\Scheme_Color::get_type(),
					'value' => \Elementor\Scheme_Color::COLOR_1,
					],
				'selectors' => [
					'{{WRAPPER}} h1.entry-tag' => 'color: {{VALUE}}',
				],			
				'default' => '#333333'
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'sgm_tag_tag_typography',
				'label' => __( 'tag Typography', 'sigma-theme' ),
				'scheme' => Scheme_Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} h1.entry-tag ',
			]
		);

		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'sgm_tag_border',
				'label' => __( 'Border', 'sigma-theme' ),
				'selector' => '{{WRAPPER}} h1.entry-tag ',
			]
		);
		
        $this->end_controls_section();       
	}

    protected function render() {
        $settings = $this->get_settings_for_display();
        $template = \SigmaCore\SigmaTemplateBuilder\SigmaTemplateBuilder::GetInstance();
        if($template->IsRealRender())
        {
        $post_tags = $template->GetRelatedPostField("the_tags");
        $separator = ' | ';
            foreach ($post_tags as $tag) {
                $output .= '<a href="' . get_tag_link($tag->term_id) . '">' . $tag->name . '</a>' . $separator;
            }
            return trim($output, $separator);
        }
        else
        {
        $post_tags = $template->GetRelatedPostField("the_tags");
        $separator = ' | ';
            foreach ($post_tags as $tag) {
                $output .= '<a href="' . get_tag_link($tag->term_id) . '">' . $tag->name . '</a>' . $separator;
            }
            return trim($output, $separator);
        }
    }
}